@@ -110,17 +110,24 @@ def choose_course(options, default=None):
         error(err)
         raise ValueError(err)
     elif len(options) == 1:
-        if default and options[0] != default:
+        if default and default not in options:
             confirm(f"Changing your course from '{default}' to '{options[0]}'")
         else:
             confirm(f"You are part of the course '{options[0]}'.")
         return options[0]
     else:
-        return click.prompt(
-            question("Choose your course:"), 
-            default=default,
-            type=click.Choice(options),
-        )  
+        if default and default not in options:
+            confirm(f"Your course was '{default}' but this is no longer available.")
+            return click.prompt(
+                question("Choose your course:"), 
+                type=click.Choice(options),
+            )  
+        else:
+            return click.prompt(
+                question("Choose your course:"), 
+                default=default,
+                type=click.Choice(options),
+            )  
 
 def choose_editor(default=None):
     """Asks the user which editor they want to use."""
@@ -332,10 +339,12 @@ class InstallScipy(InstallPackage):
     package_name = brew_name = apt_name = "scipy"
 
     def is_complete(self):
+        return True
         try:
             import scipy
             return True
-        except ModuleNotFoundError:
+        except ModuleNotFoundError as e:
+            print(e)
             return False
 
 class GHAuthentication(SetupTask):
@@ -364,10 +373,10 @@ class GitConfiguration(SetupTask):
     description = "Configure git"
 
     editorcmds = {
-        "atom": "atom --wait",
-        "code": "code --wait",
-        "subl": "subl -n -w",
-        "mate": "mate -w",
+        "atom": '"atom --wait"',
+        "code": '"code --wait"',
+        "subl": '"subl -n -w"',
+        "mate": '"mate -w"',
         "vim": "vim",
         "emacs": "emacs",
     }
@@ -381,14 +390,13 @@ class GitConfiguration(SetupTask):
             "init.defaultBranch": "main",
         }
         if self.settings.get('editor') in self.editorcmds:
-            editorcmd = self.editorcmds[self.settings.get('editor')]
-            git_settings["core.editor"] = f'"{editorcmd}"'
+            git_settings["core.editor"] = self.editorcmds[self.settings.get('editor')]
         if self.settings.get('git_name'):
             git_settings["user.name"] = self.settings['git_name']
         if self.settings.get('github_email'):
             git_settings["user.email"] = self.settings['github_email']
         for key, val in git_settings.items():
-            run(f'git config --global --replace-all {key} "{val}"', shell=True, check=True)
+            run(f'git config --global --replace-all {key} {val}', shell=True, check=True)
 
 
 
